Results can be displayed in the console. Outputs are saved in data frame.
Arguments
RDA
The RDA object : RDA <- vegan::rda(mtcars_quant~gear+carb,data=mtcars)
RDA.synth
TRUE or FALSE. If TRUE, displays the RDA model's global variance partitioning. Default is TRUE.
RDA.anova
TRUE or FALSE. If TRUE, prints the results of the vegan function anova.cca, displaying the variance partitioning by terms in the RDA model. Default is TRUE.
nbperms
Numeric number of permutations used by the RDA.anova function. Default is 1000.
RDA.Table
TRUE or FALSE. TRUE : calculate and display the variance percentage of considered factor / total unconstrained variance. Default : TRUE.